@@ -16,6 +16,9 @@
 import gtk
 import gobject
 import os
+import gettext
+from gettext import gettext as _
+gettext.textdomain('quickly-widgets')
 
 #TODO: stop using **kwargs and go back to named arguments so you can pass them from the function to the class
 
@@ -96,7 +99,7 @@ class Prompt(gtk.Dialog):
         self.content_box.show()
         label.show()
 
-def string(title = "Input String", text = "Input a String:", default_value = ""):
+def string(title = _("Input String"), text = _("Input a String:"), default_value = ""):
     """string - prompts to enter a string via a dialog box.
 
     aguments:
@@ -138,7 +141,7 @@ class StringPrompt(Prompt):
     A StringPrompt is a Prompt which is gtk.Dialog
 
     """
-    def __init__(self, title = "Input String", text = "Input a String:", default_value = ""):
+    def __init__(self, title = _("Input String"), text = _("Input a String:"), default_value = ""):
         """Create a StringPrompt
         arguments:
         title - a string to be the title of the dialog
@@ -160,7 +163,7 @@ class StringPrompt(Prompt):
         """
         return self._entry.get_text()
 
-def date(title = "Choose Date", text = "Choose a Date:", default_value = None):
+def date(title = _("Choose Date"), text = _("Choose a Date:"), default_value = None):
     """date - prompts to enter a date using a calendar via a dialog box.
 
     aguments:
@@ -208,7 +211,7 @@ class DatePrompt(Prompt):
 
     """
 
-    def __init__(self, title = "Choose Date", text = "Choose a Date:", default_value = None):
+    def __init__(self, title = _("Choose Date"), text = _("Choose a Date:"), default_value = None):
         """Creates a DatePrompt
         title - a string to be the title of the dialog
         text - a string to provide a prompt for the user within dialog
@@ -235,7 +238,7 @@ class DatePrompt(Prompt):
 
         return self._calendar.get_date()
 
-def integer(title = "Enter Number", text = "Enter an Integer Value:", 
+def integer(title = _("Enter Number"), text = _("Enter an Integer Value:"), 
             default_value=0, min_value = -1000000000, max_value=1000000000,
             step = 1):
     """integer - prompts to enter an integer using a spinner via a dialog box.
@@ -294,7 +297,7 @@ class IntegerPrompt(Prompt):
 
     """
 
-    def __init__(self, title="Enter Number", text="Enter an Integer Value:",
+    def __init__(self, title=_("Enter Number"), text=_("Enter an Integer Value:"),
             default_value=0, min_value = -1000000000, max_value=1000000000,
             step = 1):
         """Creates an Integer Prompt
@@ -312,7 +315,7 @@ class IntegerPrompt(Prompt):
     def get_value(self):
             return self._spinner.get_value_as_int()
 
-def decimal(title="Enter Price", text="Choose a Price:", 
+def decimal(title=_("Enter Price"), text=_("Choose a Price:"), 
           default_value=0, min_value=-1000000000, max_value=1000000000,
           step=1,digits=20):
     """decimal - prompts to enter a number that inlcudes
@@ -375,7 +378,7 @@ class DecimalPrompt(Prompt):
 
     """
 
-    def __init__(self, title="Enter Number", text="Enter an Integer Value:",
+    def __init__(self, title=_("Enter Number"), text=_("Enter an Integer Value:"),
                     default_value=0, min_value=-1000000000, max_value=1000000000,
                     step=1, digits=20):
         """Creates a DecimalPrompt
@@ -421,7 +424,7 @@ class DecimalPrompt(Prompt):
     def get_value(self):
             return self._spinner.get_value()
 
-def price(title="Enter Price", text="Choose a Price:", 
+def price(title=_("Enter Price"), text=_("Choose a Price:"), 
           default_value=0, min_value=-1000000000, max_value=1000000000,
           step=1):
     """price - prompts to enter a number up to the 
@@ -482,7 +485,7 @@ class PricePrompt(DecimalPrompt):
 
     """
 
-    def __init__(self, title="Enter Price", text="Choose a Price:", 
+    def __init__(self, title=_("Enter Price"), text=_("Choose a Price:"), 
           default_value=0, min_value=-1000000000, max_value=1000000000,
           step=1):
         """Creates a DecimalPrompt
@@ -513,7 +516,7 @@ class PricePrompt(DecimalPrompt):
                               max_value, step)
         self._spinner.set_digits(2)
 
-def yes_no(title = "Choose Yes or No", text = "", yes="", no=""):
+def yes_no(title = _("Choose Yes or No"), text = "", yes="", no=""):
     """yes_no - prompts the user to choose between two options,
         one "yes" and one "no", though typically the button labels
         should be set as verbs.
@@ -564,7 +567,7 @@ class YesNoPrompt(gtk.Dialog):
 
     """
 
-    def __init__(self, title="Choose an option",text="",yes="",no=""):
+    def __init__(self, title=_("Choose an option"),text="",yes="",no=""):
         """creaets a YesNoPrompt.
         
         aguments:
@@ -609,7 +612,7 @@ class YesNoPrompt(gtk.Dialog):
         label.show()
         img.show()
 
-def warning(title = "Warning", text = ""):
+def warning(title = _("Warning"), text = ""):
     """warning - displays a warning to the user, includes an appropriate icon
     and an OK button
 
@@ -628,7 +631,7 @@ def warning(title = "Warning", text = ""):
     w.destroy()
     return response
 
-def error(title = "ERROR", text = ""):
+def error(title = _("Error"), text = ""):
     """error - displays an error to the user, includes an appropriate icon
     and an OK button
 
@@ -648,7 +651,7 @@ def error(title = "ERROR", text = ""):
     return response
 
 
-def info(title = "Information", text = ""):
+def info(title = _("Information"), text = ""):
     """info - displays information to the user, includes an appropriate
     icon and an OK button
 
@@ -711,7 +714,7 @@ class Alert(gtk.Dialog):
         self._image.set_from_stock(image,gtk.ICON_SIZE_DIALOG)        
     
 
-def save_image_file(title="Choose an Image",path=None):
+def save_image_file(title=_("Choose an Image"),path=None):
     """save_image_file - prompts the user to choose an image file
 
     aguments:
@@ -855,7 +858,7 @@ class OpenImageDialog(ImageDialog):
         """
         ImageDialog.__init__(self,gtk.FILE_CHOOSER_ACTION_OPEN, gtk.STOCK_OPEN, title,path)
 
-def open_image_file(title="Choose an Image",path=None):
+def open_image_file(title=_("Choose an Image"),path=None):
     """open_image_file - prompts the user to choose an image file
 
     aguments:
@@ -876,7 +879,7 @@ def open_image_file(title="Choose an Image",path=None):
     oid.destroy()
     return (response, value)
 
-def choose_directory(title="Choose a Directory",path=None):
+def choose_directory(title=_("Choose a Directory"),path=None):
     """choose_directory - prompts the user to choose an directory
 
     aguments:
@@ -890,6 +893,7 @@ def choose_directory(title="Choose a Directory",path=None):
     dialogv(gtk.RESPONSE_DELETE_EVENT)
 
     """
+
     dcd = DirectoryChooserDialog(title, path)
     response = dcd.run()
     value = dcd.get_filename()
@@ -955,21 +959,21 @@ if __name__ == "__main__":
         print "response was OK"
     else:
         print "response was not OK"
-    print "selected locations was " + val
+    print "selected locations was " + str(val)
 
     response, val = save_image_file("image save test")
     if response == gtk.RESPONSE_OK:
         print "response was OK"
     else:
         print "response was not OK"
-    print "selected locations was " + val
+    print "selected locations was " + str(val)
 
     reponse, val = string("String select test","String select test")
     if response == gtk.RESPONSE_OK:
         print "response was OK"
     else:
         print "response was not OK"
-    print "string was " + val
+    print "string was " + str(val)
 
     reponse, val = date("Date select test","Date select test")
     if response == gtk.RESPONSE_OK:
