@@ -16,7 +16,7 @@
 import gtk
 import gobject
 from grid_column import StringColumn, CurrencyColumn, CheckColumn
-from grid_column import IntegerColumn, TagsColumn
+from grid_column import IntegerColumn, TagsColumn, DateColumn
 
 def get_column(key, index, dictionary_index, editable):
     if key.lower() == "id":
@@ -29,6 +29,9 @@ def get_column(key, index, dictionary_index, editable):
         return TagsColumn(key, index, dictionary_index, editable)
     elif key.lower().endswith(" count"):
         return IntegerColumn(key, index, dictionary_index, editable)
+    elif key.lower().endswith("date"):
+        return DateColumn(key, index, dictionary_index, editable)
+
     else:
         return StringColumn(key, index, dictionary_index, editable)
 
