@@ -100,8 +100,8 @@ class DictionaryGrid(gtk.TreeView):
         """
 
         gtk.TreeView.__init__(self)
-
         self.list_store = None
+        self.unfiltered_store = None
         self._keys = keys
         self._editable = editable
         if dictionaries is None:
@@ -137,7 +137,7 @@ class DictionaryGrid(gtk.TreeView):
         self.emit("selection-changed", self.selected_rows)
 
     def __edited_toggled(self, cell, path, col):
-        iter = self.list_store.get_iter(path)
+        iter = self.get_model().get_iter(path)
         key = col.key
         active = not cell.get_active()
         self.__edited(cell, path, active, col)
@@ -148,16 +148,15 @@ class DictionaryGrid(gtk.TreeView):
         has been edited.
 
         """
-        iter = self.list_store.get_iter(path)
+        iter = self.get_model().get_iter(path)
         row_dict = self.get_model().get_value(iter,len(self.keys))
         key = col.key
-        dictionary = self.list_store.get_value(iter,len(self.keys))
+        dictionary = self.get_model().get_value(iter,len(self.keys))
         self.emit("cell-edited",cell, path, key, new_val, row_dict)
 
-
     @property
     def keys(self):
-        """ set keys - A list of strings to act as keys for the
+        """ keys - A list of strings to act as keys for the
         backing dictionaries and the default titles for the columns.
 
         Setting this property will cause the widget to reload.
@@ -187,6 +186,35 @@ class DictionaryGrid(gtk.TreeView):
         #refresh the treeview if possible
         self._refresh_treeview()
 
+    @property
+    def columns(self):
+        """ columns - A dictionary of the GridColumns indexed by the
+        keys for that column. This allows access to columns by the key,
+        for example to change the title of a specific column:
+        grid.columns["complete?"].set_title(_("Completed"))
+
+        This property is read only.
+
+        """
+
+        cols = {}
+        for c in self.get_columns():
+            cols[c.key] = c
+        return cols
+
+    def set_column_titles(self, titles):
+        """set_column_titles - sets the specified titles for the GridColumns
+        in the DictionaryGrid. Use a dictionary of strings indexed by keys.
+        For example:
+        titles = {"complete?":_("Complete"),"id":_("ID")}
+        grid.set_column_titles(titles)
+        
+        """
+
+        for t in titles:
+            if t in self.columns:
+                self.columns[t].set_title(titles[t])
+
     def get_dictionaries_copy(self):
         """get_dictionaries_copy -returns a copy of the dictionaries in
         the dictionary grid.
@@ -208,7 +236,7 @@ class DictionaryGrid(gtk.TreeView):
                 if k not in key_collector and not k.startswith("__"):
                     key_collector.append(k)
         
-        self.keys = key_collector
+        self._keys = key_collector
 
     def _refresh_treeview(self):
         """
@@ -237,6 +265,7 @@ class DictionaryGrid(gtk.TreeView):
 
         #apply the model to the Treeview if possible
         if self.list_store != None:
+            self.unfiltered_store = self.list_store
             self.set_model(self.list_store)
 
     def append_row(self, dictionary):
@@ -317,6 +346,7 @@ class DictionaryGrid(gtk.TreeView):
 
         #get the selected rows, and return if nothing is selected
         model, rows = self.get_selection().get_selected_rows()
+
         if len(rows) == 0:
             return
 
@@ -324,9 +354,22 @@ class DictionaryGrid(gtk.TreeView):
         next_to_select = rows[-1][0] + 1 - len(rows)
         
         #loop through and remove
-        iters = [model.get_iter(path) for path in rows]
-        for i in iters:
-            self.get_model().remove(i)
+
+        if type(model) is not gtk.ListStore:
+            iters = [model.get_model().get_iter(path) for path in rows]
+            store_iters = []
+
+            for i in iters:
+                store_iters.append(model.get_model().convert_iter_to_child_iter(i))
+
+            for store_iter in store_iters:
+                self.unfiltered_store.remove(store_iter)
+
+        else:
+            iters = [model.get_iter(path) for path in rows]
+
+            for i in iters:
+                model.remove(i)
 
         #select a row for the user, nicer that way
         rows_remaining = len(self.get_model()) 
