@@ -84,13 +84,18 @@ GridFilter is associate with the column.
 
 For example, CurrencyColumn defines the following class variables:
 column_type = gobject.TYPE_STRING
-default_filter = grid_filter.NumericFilterCombo
+default_filter = grid_filter.NumericFilterBox
 
 """
 
 
 
 import sys
+import datetime
+import gettext
+from gettext import gettext as _
+gettext.textdomain('quickly-widgets')
+
 try:
     import pygtk
     pygtk.require("2.0")
@@ -98,6 +103,7 @@ try:
     import gobject
     import grid_filter
 
+
 except Exception, inst:
     print "some dependencies for GridFilter are not available"
     raise inst
@@ -113,7 +119,7 @@ class StringColumn( gtk.TreeViewColumn ):
 
     column_type = gobject.TYPE_STRING
     __sort_order = None
-    default_filter = grid_filter.StringFilterCombo
+    default_filter = grid_filter.StringFilterBox
     def __init__(self, key, index, dictionary_index, editable=True, format_function = None ):
         """Creates a StringColumn
 
@@ -329,7 +335,7 @@ class CurrencyColumn( StringColumn ):
     """
 
     column_type = gobject.TYPE_STRING
-    default_filter = grid_filter.NumericFilterCombo
+    default_filter = grid_filter.NumericFilterBox
     def __init__(self, key, index,dictionary_index, editable=True ):
         """Creates a CurrencyColumn
 
@@ -484,13 +490,13 @@ class CurrencyColumn( StringColumn ):
 
 class TagsColumn( StringColumn ):
     """TagsColumn - A specialization of a StringColumn that differs
-    only in that it uses a TagsFilterCombo for filtering in any
+    only in that it uses a TagsFilterBox for filtering in any
     attached GridFilter.
 
     """
 
     column_type = gobject.TYPE_STRING
-    default_filter = grid_filter.TagsFilterCombo
+    default_filter = grid_filter.TagsFilterBox
 
 
 class IntegerColumn( StringColumn ):
@@ -502,7 +508,7 @@ class IntegerColumn( StringColumn ):
     """
 
     column_type = gobject.TYPE_STRING
-    default_filter = grid_filter.NumericFilterCombo
+    default_filter = grid_filter.IntegerFilterBox
 
     def __init__(self, key, index, dictionary_index, editable=True ):
         """Creates an IntegerColumn
@@ -640,7 +646,7 @@ class CheckColumn( gtk.TreeViewColumn ):
     """
 
     column_type = gobject.TYPE_INT
-    default_filter = grid_filter.CheckFilterCombo
+    default_filter = grid_filter.CheckFilterBox
 
     def __init__(self, key, index, dictionary_index, editable=True, format_function = None ):
         """Creates a StringColumn
@@ -753,7 +759,7 @@ class CheckColumn( gtk.TreeViewColumn ):
             else:
                 return 0
         elif type(val) is str:
-            if val.lower() == "yes":
+            if val.lower() == _("yes"):
                 return 1
             else:
                 return 0
@@ -790,3 +796,124 @@ class CheckColumn( gtk.TreeViewColumn ):
                 return False
         else:
             return bool(val)
+
+class DateColumn( StringColumn ):
+    """DateColumn - display data in date format. Uses a gtk.Calendar
+    to display data and support editing if enabled. Store real values as tuple.
+
+    Inherits from StringColumn.
+
+    """
+
+    column_type = gobject.TYPE_STRING
+    default_filter = grid_filter.DateFilterBox
+
+    def __init__(self, key, index,dictionary_index, editable=True ):
+        """Creates a Date
+
+        Arguments:
+        key - the key from the dict for the row. Also used as the title for the
+        column by default.
+        index - the position of the column in the grid.
+
+        dictionary_index - the index in the ListStore where the dictionary
+        for the row is stored. Typically len(dict).
+
+        editable - False if the column does not allow the user to edit the
+        values in the column. Defaults to True.
+
+        """
+        self._editable = editable
+        StringColumn.__init__( self, key, index, dictionary_index, editable)
+       
+    def _initialize_renderer( self, editable, index ):
+        """_initialize_renderer - internal function called to set up the
+        CellRenderer for the column.
+
+        arguments:
+
+        editable - True if the column should support user editing.
+
+        index - the position of the column in the grid
+
+        """
+
+        self.renderer = CellRendererDate()
+        self.renderer.set_property('editable',self._editable)
+        self.renderer.connect("edited", self._cell_edited)
+        
+class CellRendererDate(gtk.CellRendererText):
+
+    __gtype_name__ = 'CellRendererDate'
+
+    def __init__(self):
+        gtk.CellRendererText.__init__(self)
+        self.date_format = '%Y-%m-%d'
+
+        self.calendar_window = None
+        self.calendar = None
+
+    def _create_calendar(self, treeview):
+        self.calendar_window = gtk.Dialog(parent=treeview.get_toplevel())
+        self.calendar_window.action_area.hide()
+        self.calendar_window.set_decorated(False)
+        self.calendar_window.set_property('skip-taskbar-hint', True)
+
+        self.calendar = gtk.Calendar()
+        self.calendar.display_options(gtk.CALENDAR_SHOW_DAY_NAMES | gtk.CALENDAR_SHOW_HEADING)
+        self.calendar.connect('day-selected-double-click', self._day_selected, None)
+        self.calendar.connect('key-press-event', self._day_selected)
+        self.calendar.connect('focus-out-event', self._selection_cancelled)
+        self.calendar_window.set_transient_for(None) # cancel the modality of dialog
+        self.calendar_window.vbox.pack_start(self.calendar)
+
+        # necessary for getting the (width, height) of calendar_window
+        self.calendar.show()
+        self.calendar_window.realize()
+
+    def do_start_editing(self, event, treeview, path, background_area, cell_area, flags):
+        if not self.get_property('editable'):
+            return
+
+        if not self.calendar_window:
+            self._create_calendar(treeview)
+
+        # select cell's previously stored date if any exists - or today
+        if self.get_property('text'):
+            date = datetime.datetime.strptime(self.get_property('text'), self.date_format)
+        else:
+            date = datetime.datetime.today()
+
+        self.calendar.freeze() # prevent flicker
+        (year, month, day) = (date.year, date.month - 1, date.day) # datetime's month starts from one
+        self.calendar.select_month(int(month), int(year))
+        self.calendar.select_day(int(day))
+        self.calendar.thaw()
+
+        # position the popup below the edited cell (and try hard to keep the popup within the toplevel window)
+        (tree_x, tree_y) = treeview.get_bin_window().get_origin()
+        (tree_w, tree_h) = treeview.window.get_geometry()[2:4]
+        (calendar_w, calendar_h) = self.calendar_window.window.get_geometry()[2:4]
+        x = tree_x + min(cell_area.x, tree_w - calendar_w + treeview.get_visible_rect().x)
+        y = tree_y + min(cell_area.y, tree_h - calendar_h + treeview.get_visible_rect().y)
+        self.calendar_window.move(x, y)
+    
+        response = self.calendar_window.run()
+        self.calendar_window.hide()
+        if response == gtk.RESPONSE_OK:
+            (year, month, day) = self.calendar.get_date()
+            date = datetime.date(year, month + 1, day).strftime(self.date_format) # gtk.Calendar's month starts from zero
+            self.emit('edited', path, date)
+            
+        return None # don't return any editable, our gtk.Dialog did the work already
+
+    def _day_selected(self, calendar, event):
+        # event == None for day selected via doubleclick
+        if not event or event.type == gtk.gdk.KEY_PRESS and gtk.gdk.keyval_name(event.keyval) == 'Return':
+            self.calendar_window.response(gtk.RESPONSE_OK)
+            return True
+
+    def _selection_cancelled(self, calendar, event):
+        self.calendar_window.response(gtk.RESPONSE_CANCEL)
+        return True
+
