@@ -40,7 +40,7 @@ Configuring
 for each row and return True if the results should cause the row to
 be displayed and False if the row should not be displayed
 
-blank_filter = BlankFilterCombo()
+blank_filter = BlankFilterBox()
 blank_filter.append("=",custom_equals_function )
 blank_filter.append("<>",custom_no_equals_function )
 
@@ -49,20 +49,17 @@ filt = GridFilter(grid, filter_hints)
 filt.show()
 
 Extending
-A custom filter combo is easiest to create by deriving from BlankFilterCombo
-and using the BlankFilterCombo.append function to display new filters.
+A custom filter combo is easiest to create by deriving from BlankFilterBox
+and using the BlankFilterBox.append function to display new filters.
 
-class StringFilterCombo( BlankFilterCombo ):
+class StringFilterBox( BlankFilterBox ):
  def __init__(self):
-  BlankFilterCombo.__init__(self)
+  BlankFilterBox.__init__(self)
   self.append("contains",lambda x,y: x.find(y) > -1)
   self.append("does not contain",lambda x,y: x.find(y) == -1)
   self.append("starts with",lambda x,y: x.startswith(y))
   self.append("ends with",lambda x,y: x.endswith(y))
 
-Set the property requires_input to False to hide the gtk.TextEntry that is
-automatically created for taking user input.
-
 Filter UI could be created to use widgets other than gtk.Combo so long as
 the widget has a get_model function that returns a gtk.ListStore with
 filtering functions stored as the last value (column) in the liststore.
@@ -70,6 +67,11 @@ filtering functions stored as the last value (column) in the liststore.
 """
 
 import sys
+import datetime
+import gettext
+from gettext import gettext as _
+gettext.textdomain('quickly-widgets')
+
 try:
  import pygtk
  pygtk.require("2.0")
@@ -97,11 +99,10 @@ class GridFilter( gtk.VBox ):
   filter_hints - a dictionary of column keys to FilterCombo types to
   provide custom filtering. 
  
-
   """
 
   gtk.VBox.__init__( self, False, 10 )
-  self.grid = grid
+  self.grid = grid  
   self.store = grid.get_model()
   self.filter_hints = filter_hints
 
@@ -109,11 +110,11 @@ class GridFilter( gtk.VBox ):
   radio_box = gtk.HBox(False,2)
   radio_box.show()
   self.pack_start(radio_box, False, False)
-  self.and_button = gtk.RadioButton(None,"M_atch All of the following", True)
+  self.and_button = gtk.RadioButton(None,_("M_atch All of the following"), True)
   self.and_button.show()
   self.and_button.connect("toggled",self.__filter_changed)
   radio_box.pack_start(self.and_button, False, False)
-  or_button = gtk.RadioButton(self.and_button,"Match any _of the following", True)
+  or_button = gtk.RadioButton(self.and_button,_("Match any _of the following"), True)
   or_button.show()
   radio_box.pack_start(or_button, False, False)
   self.rows = []
@@ -151,6 +152,7 @@ class GridFilter( gtk.VBox ):
   requests to reapply the fitlers in the GridFilter's FilterRows.
 
   """
+
   filt = self.store.filter_new()
   sort_mod = gtk.TreeModelSort(filt)
   filt.set_visible_func(self.__filter_func, data )
@@ -220,7 +222,8 @@ class FilterRow( gtk.HBox):
    else:
     filt_combo = grid.get_columns()[i].default_filter()
          
-   heading_combo_store.append([k,filt_combo,i])
+   column_title = grid.get_columns()[i].get_title()
+   heading_combo_store.append([column_title,filt_combo,i])
 
    filt_combo.connect("changed",self.__filter_changed)
    filt_combo.show()
@@ -233,18 +236,15 @@ class FilterRow( gtk.HBox):
   self.filter_space = gtk.HBox(False,1)
   self.filter_space.show()
 
-  self.filter_entry = gtk.Entry()
-  self.filter_entry.show()
-  self.filter_entry.connect("changed",self.__filter_changed)
-
   self.column_combo.show()
-  self.pack_start(self.column_combo,False, False)
+  vb = gtk.VBox(False, 5)
+  vb.show()
+  vb.pack_start(self.column_combo, True, False)
+  self.pack_start(vb,False, False)
   self.column_combo.connect("changed",self.__column_changed)
   self.column_combo.set_active(0)
 
   self.pack_start(self.filter_space, False, False)
-  self.pack_start(self.filter_entry, False)
-
 
   button_box = gtk.HBox(False,2)
   button_box.show()
@@ -253,7 +253,10 @@ class FilterRow( gtk.HBox):
   #add a button that can create a new row in the grid filter
   add_button = gtk.Button(stock = gtk.STOCK_ADD)
   add_button.show()
-  button_box.pack_start(add_button)
+  vb2 = gtk.VBox(False, 5)
+  vb2.show()
+  vb2.pack_start(add_button, True, False)
+  button_box.pack_start(vb2, False, False)
   add_button.connect("clicked",lambda x: self.emit('add_row_requested',self) )
 
   #add a button to remove the row if applicable
@@ -282,14 +285,8 @@ class FilterRow( gtk.HBox):
   if len(self.filter_space.get_children()) > 0:
    self.filter_space.remove(self.filter_space.get_children()[0])   
   iter = widget.get_model().get_iter(widget.get_active())
-  combo = widget.get_model().get_value(iter,1)
-  if combo.requires_input:
-   self.filter_entry.show()
-   self.wait_for_input = True
-  else:
-   self.filter_entry.hide()
-   self.wait_for_input = False
-  self.filter_space.pack_start(combo, False, False)
+  filter_box = widget.get_model().get_value(iter,1)
+  self.filter_space.pack_start(filter_box, False, False)
 
  def __filter_changed(self,widget, data=None):
   """filter_changed: internal signal handler called when the FilterRow has changed.
@@ -299,9 +296,9 @@ class FilterRow( gtk.HBox):
 
   """
   
-  if self.filter_entry.get_text() != "" or not self.wait_for_input:
-   if self.__get_current_filter_combo().get_active > -1:
-    self.emit('refilter_requested',self)
+  #if not self.wait_for_input:
+  #if self.__get_current_filter_combo().get_active > -1:
+  self.emit('refilter_requested',self)
 
  def __get_current_filter_combo(self):
   """get_current_filter_combo: internal function that retrieves
@@ -324,54 +321,52 @@ class FilterRow( gtk.HBox):
   model: the treeview model containing the rows being tested
 
   """
-  #get the filter combo
   col_iter = self.column_combo.get_model().get_iter(self.column_combo.get_active())
-  combo = self.column_combo.get_model().get_value(col_iter,1)
-
-  #return if now combo is set
-  if combo.get_active() < 0:
-   return True
-
-  #return if wating for input
-  if self.wait_for_input and self.filter_entry.get_text() == "":
-   return True
- 
-
-  #get the filter function from the selection in the fitler combo
-  filt_iter = combo.get_model().get_iter(combo.get_active())
-  filt_func = combo.get_model().get_value(filt_iter,1) 
-
-  #find the column in the treeview to look in
+  filter_widget = self.column_combo.get_model().get_value(col_iter,1)
   treeview_col = self.column_combo.get_model().get_value(col_iter,2)
 
-  #pull the value out of the store
   orig_val = model.get_value(store_iter.copy(), treeview_col)
-  if orig_val == None:
-   orig_val = ""
-  return filt_func(orig_val, self.filter_entry.get_text())    
+  return filter_widget.filter(orig_val)
 
-class BlankFilterCombo( gtk.ComboBox):
- """BlankFilterCombo provides a base class for FilterCombos, as
+class BlankFilterBox( gtk.HBox):
+ """BlankFilterBox provides a base class for FilterCombos, as
  well as an empty combo that can be used without subclassing
- by calling BlankFilterCombo.append
+ by calling BlankFilterBox.append
 
  """
+ __gsignals__ = {'changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+		(gobject.TYPE_PYOBJECT,)),
+		}
+
 
- requires_input = True
  def __init__(self):
-  """create a BlankFilterCombo
-
-  After creation set requires_input = False to hide the
-  automatically created TextEntry. Use the append function
-  to add a filter.
+  """create a BlankFilterBox
 
   """
 
+  gtk.HBox.__init__(self,False)
   self.__combo_store = gtk.ListStore(gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)
-  gtk.ComboBox.__init__( self, self.__combo_store)
+  self.combo = gtk.ComboBox(self.__combo_store)
   cell = gtk.CellRendererText()
-  self.pack_start(cell, True)
-  self.add_attribute(cell, 'text', 0)
+  self.combo.pack_start(cell, True)
+  self.combo.add_attribute(cell, 'text', 0)
+  self.combo.show()
+  self.combo.connect("changed",self.__changed)
+  self.entry = gtk.Entry()
+  self.entry.show()
+  self.entry.connect("changed",self.__changed)
+  self.pack_start(self.combo, False, False)
+  self.pack_start(self.entry)
+
+ def filter(self, orig_val):
+  if self.combo.get_active() == -1:
+   return True
+  filt_iter = self.combo.get_model().get_iter(self.combo.get_active())
+  filt_func = self.combo.get_model().get_value(filt_iter,1)
+  return filt_func(orig_val)
+
+ def __changed(self, widget, data=None):
+    self.emit("changed",data)
 
  def append(self, text, func):
     """append: adds a row to the FilterCombo that includes a
@@ -386,8 +381,8 @@ class BlankFilterCombo( gtk.ComboBox):
 
     self.__combo_store.append([text, func])
 
-class StringFilterCombo( BlankFilterCombo ):
- """StringFilterCombo: A default string filter class for use in a FilterRow.
+class StringFilterBox( BlankFilterBox ):
+ """StringFilterBox: A default string filter class for use in a FilterRow.
 
     Lets the user specify if the row should be displayed based on
     containing, not containing, starting with, or ending with a user specified
@@ -396,17 +391,39 @@ class StringFilterCombo( BlankFilterCombo ):
 
  """
  def __init__(self):
-  """create a StringFilterCombo.
+  """create a StringFilterBox.
 
   """
-  BlankFilterCombo.__init__(self)
-  self.append("contains",lambda x,y: x.find(y) > -1)
-  self.append("does not contain",lambda x,y: x.find(y) == -1)
-  self.append("starts with",lambda x,y: x.startswith(y))
-  self.append("ends with",lambda x,y: x.endswith(y))
 
-class TagsFilterCombo( BlankFilterCombo ):
- """TagsFilterCombo: A default tag filter class for use in a FilterRow.
+  BlankFilterBox.__init__(self)
+  self.append(_("contains"),self.contains)
+  self.append(_("does not contain"),self.not_contains)
+  self.append(_("starts with"),self.starts_with)
+  self.append(_("ends with"),self.ends_with)
+
+ def contains(self, orig_val):
+  if len(self.entry.get_text()) == 0:
+   return True
+  return orig_val.find(self.entry.get_text()) > -1
+
+ def not_contains(self, orig_val):
+  if len(self.entry.get_text()) == 0:
+   return True
+  return orig_val.find(self.entry.get_text()) == -1
+
+ def starts_with(self, orig_val):
+  if len(self.entry.get_text()) == 0:
+   return True
+  return orig_val.startswith(self.entry.get_text())
+
+ def ends_with(self, orig_val):
+  if len(self.entry.get_text()) == 0:
+   return True
+  return orig_val.endswith(self.entry.get_text())
+
+
+class TagsFilterBox( BlankFilterBox ):
+ """TagsFilterBox: A default tag filter class for use in a FilterRow.
 
     Lets the user specify if the row should be displayed based on
     containing a one tag or all tags. Assumes tags are seperated by
@@ -415,107 +432,284 @@ class TagsFilterCombo( BlankFilterCombo ):
  """
 
  def __init__(self):
-  BlankFilterCombo.__init__(self)
+  BlankFilterBox.__init__(self)
+  self.append(_("has any of these tags"), self._filter_any)
+  self.append(_("has all of these tags"), self._filter_all)
+  self.append(_("does not have one of these tags"), self._filter_not)
+  self.append(_("does not have any of these tags"), self._filter_not_all)
 
-  def _filter_any(bug_tags_s, filter_tags):
-      """
-      _filter_any: filter function that hides rows
-      if none of the tags supplied in "bugs_tags_s" are found
-      in the gtk.TextEntry.
+ def _filter_any(self, orig_val):
+  """
+  _filter_any: filter function that hides rows
+  if none of the tags supplied in "bugs_tags_s" are found
+  in the gtk.TextEntry.
 
-      Do not call directly
+  Do not call directly
 
-      """
+  """
 
-      tags_on_bug = bug_tags_s.split()
-      tags_in_filter = filter_tags.split()
+  if len(self.entry.get_text()) == 0:
+   return True
 
-      for tag in tags_in_filter:
-          if tag in tags_on_bug:
-              return True
-      return False
+  tags_on_bug = orig_val.split()
+  tags_in_filter = self.entry.get_text().split()
 
-  def _filter_all(bug_tags_s, filter_tags):
-      """
-      _filter_any: filter function that hides rows
-      if not all of the tags supplied in "bugs_tags_s" are found
-      in the gtk.TextEntry.
+  for tag in tags_in_filter:
+   if tag in tags_on_bug:
+    return True
+  return False
 
-      Do not call directly
+ def _filter_all(self, orig_val):
+  """
+  _filter_any: filter function that hides rows
+  if not all of the tags supplied in "bugs_tags_s" are found
+  in the gtk.TextEntry.
 
-      """
+  Do not call directly
 
+  """
+  if len(self.entry.get_text()) == 0:
+   return True
 
-      tags_on_bug = bug_tags_s.split()
-      tags_in_filter = filter_tags.split()
+  tags_on_bug = orig_val.split()
+  tags_in_filter = self.entry.get_text().split()
 
-      for tag in tags_in_filter:
-          if tag not in tags_on_bug:
-              return False
-      return True
+  for tag in tags_in_filter:
+   if tag not in tags_on_bug:
+    return False
+  return True
 
-  def _filter_not(bug_tags_s, filter_tags):
-      """
-      _filter_not: filter function that hides rows
-      if one of the tags supplied in "bugs_tags_s" are found
-      in the gtk.TextEntry.
+ def _filter_not(self, orig_val):
+  """
+  _filter_not: filter function that hides rows
+  if one of the tags supplied in "bugs_tags_s" are found
+  in the gtk.TextEntry.
 
-      Do not call directly
+  Do not call directly
 
-      """
+  """
+  if len(self.entry.get_text()) == 0:
+   return True
 
-
-      tags_on_bug = bug_tags_s.split()
-      tags_in_filter = filter_tags.split()
+  tags_on_bug = orig_val.split()
+  tags_in_filter = self.entry.get_text().split()
               
-      for tag in tags_in_filter:
-          if tag not in tags_on_bug:
-              return True
-      return False
+  for tag in tags_in_filter:
+   if tag not in tags_on_bug:
+    return True
+  return False
 
-  def _filter_not_all(bug_tags_s, filter_tags):
-      """
-      _filter_not all: filter function that hides rows
-      if all of the tags supplied in "bugs_tags_s" are found
-      in the gtk.TextEntry.
+ def _filter_not_all(self, orig_val):
+  """
+  _filter_not all: filter function that hides rows
+  if all of the tags supplied in "bugs_tags_s" are found
+  in the gtk.TextEntry.
 
-      Do not call directly
+  Do not call directly
 
-      """
+  """
+  if len(self.entry.get_text()) == 0:
+   return True
 
+  tags_on_bug = orig_val.split()
+  tags_in_filter = self.entry.get_text().split()
 
-      tags_on_bug = bug_tags_s.split()
-      tags_in_filter = filter_tags.split()
-
-      for tag in tags_in_filter:
-          if tag in tags_on_bug:
-              return False
-      return True
+  for tag in tags_in_filter:
+   if tag in tags_on_bug:
+    return False
+   return True
   
-  self.append("has any of these tags", _filter_any)
-  self.append("has all of these tags", _filter_all)
-  self.append("does not have one of these tags", _filter_not)
-  self.append("does not have any of these tags", _filter_not_all)
+class IntegerFilterBox( gtk.HBox ):
+ """
 
-class CheckFilterCombo( BlankFilterCombo ):
+ """
+ __gsignals__ = {'changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+		(gobject.TYPE_PYOBJECT,)),
+		}
+
+ def __init__(self):
+  gtk.HBox.__init__(self, False, 10)
+  self.__combo_store = gtk.ListStore(gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)
+  self.combo = gtk.ComboBox(self.__combo_store)
+  cell = gtk.CellRendererText()
+  self.combo.pack_start(cell, True)
+  self.combo.add_attribute(cell, 'text', 0)
+  self.combo.show()
+  self.combo.connect("changed",self.__changed)
+  adj = gtk.Adjustment()
+  self.spinner = gtk.SpinButton()
+  self.spinner.set_activates_default(True)
+  self.spinner.show()
+  self.spinner.set_numeric(True)
+
+  self.spinner.connect("input",self.__changed)
+  self.pack_start(self.combo, False, False)
+  self.pack_start(self.spinner)
+  self.__combo_store.append(["=",self._equals])
+  self.__combo_store.append(["<",self._less_than])
+  self.__combo_store.append([">",self._greater_than])
+  self.__combo_store.append(["<=",self._less_than_equals])
+  self.__combo_store.append([">=",self._greater_than_equals])
+
+
+ def __changed(self, widget, data=None):
+    self.emit("changed",data)
+
+ def filter(self, orig_val):
+  if self.combo.get_active() == -1:
+       return True
+
+  filt_iter = self.combo.get_model().get_iter(self.combo.get_active())
+  filt_func = self.combo.get_model().get_value(filt_iter,1)
+  return filt_func(orig_val)
+
+ def _equals(self, orig_val):
+  return int(orig_val) == int(self.spinner.get_value())
+
+ def _less_than(self, orig_val):
+  return orig_val < self.spinner.get_value_as_int()
+
+ def _greater_than(self, orig_val):
+  return orig_val > self.spinner.get_value_as_int()
+
+ def _less_than_equals(self, orig_val):
+  return orig_val <= self.spinner.get_value_as_int()
+
+ def _greater_than_equals(self, orig_val):
+  return orig_val >= self.spinner.get_value_as_int()
+
+class DateFilterBox( gtk.HBox ):
+ """DateFilterCombo: A default date filter class for use in a FilterRow.
+
+    Lets the user specify if the row should be displayed based on
+    the settings in a date widget.
+
+ """
+ __gsignals__ = {'changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+		(gobject.TYPE_PYOBJECT,)),
+		}
+
+ def __init__(self):
+  """create a CheckFilterCombo
+  
+  """
+  gtk.HBox.__init__(self, False, 10)
+
+  self.__combo_store = gtk.ListStore(gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)
+  self.combo = gtk.ComboBox(self.__combo_store)
+  cell = gtk.CellRendererText()
+  self.combo.pack_start(cell, False)
+  self.combo.add_attribute(cell, 'text', 0)
+  self.combo.show()
+  self.combo.connect("changed",self.__changed)
+
+  self.__combo_store.append([ _("before"),self.before ])
+  self.__combo_store.append([ _("on or before"),self.on_before ])
+  self.__combo_store.append([ _("on"), self.on_date ])
+  self.__combo_store.append([ _("on or after"),self.on_after ])
+  self.__combo_store.append([ _("after"),self.after ])
+
+  self.calendar = gtk.Calendar()
+  self.calendar.show()
+  self.calendar.connect("day-selected", self.__changed)
+  vb = gtk.VBox(False, 5)
+  vb.show()
+  vb.pack_start(self.combo, True, False)
+  self.pack_start(vb, False, False)
+  self.pack_start(self.calendar, False, False)
+
+ def before(self, orig_val):
+   stored_date, target_date = self.__get_dates(orig_val, self.calendar.get_date())
+   return stored_date < target_date
+
+ def on_before(self, orig_val):
+   stored_date, target_date = self.__get_dates(orig_val, self.calendar.get_date())
+   return stored_date <= target_date
+
+ def on_date(self, orig_val):
+   stored_date, target_date = self.__get_dates(orig_val, self.calendar.get_date())
+   return stored_date == target_date
+
+ def on_after(self, orig_val):
+   stored_date, target_date = self.__get_dates(orig_val, self.calendar.get_date())
+   return stored_date >= target_date
+
+ def after(self, orig_val):
+   stored_date, target_date = self.__get_dates(orig_val, self.calendar.get_date())
+   return stored_date > target_date
+
+ def __get_dates(self, orig_val, target_date):
+   target_date = self.calendar.get_date()
+   target_date = datetime.date(int(target_date[0]),int(target_date[1] + 1),int(target_date[2]))
+   p = orig_val.split("-")
+   stored_date = datetime.date(int(p[0]),int(p[1]),int(p[2]))   
+   return (stored_date, target_date)
+
+ def filter(self, orig_val):
+  if self.combo.get_active() == -1:
+   return True
+
+  filt_iter = self.combo.get_model().get_iter(self.combo.get_active())
+  filt_func = self.combo.get_model().get_value(filt_iter,1)
+  return filt_func(orig_val)
+
+ def __changed(self, widget, data=None):
+  self.emit("changed",data)
+
+
+class CheckFilterBox( gtk.HBox ):
  """CheckFilterCombo: A default checkbox filter class for use in a FilterRow.
 
     Lets the user specify if the row should be displayed based on
     whether a Checkbox is active, inactive, or not set.
 
  """
+ __gsignals__ = {'changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
+		(gobject.TYPE_PYOBJECT,)),
+		}
 
  def __init__(self):
   """create a CheckFilterCombo
   
   """
-  BlankFilterCombo.__init__( self )
-  self.append("checked",lambda x,y: x == 1  )
-  self.append("not Checked",lambda x,y: x == 0  )
-  self.append("unset",lambda x,y: x == -1 )
-  self.requires_input = False
+  gtk.HBox.__init__(self, False, 10)
 
-class NumericFilterCombo( BlankFilterCombo ):
+  self.__combo_store = gtk.ListStore(gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)
+  self.combo = gtk.ComboBox(self.__combo_store)
+  cell = gtk.CellRendererText()
+  self.combo.pack_start(cell, True)
+  self.combo.add_attribute(cell, 'text', 0)
+  self.combo.show()
+  self.combo.connect("changed",self.__changed)
+
+  self.__combo_store.append([ _("checked"),self.filter_checked ])
+  self.__combo_store.append([ _("not Checked"),self.filter_not_checked ])
+  self.__combo_store.append([ _("unset"), self.filter_unset ])
+
+  self.pack_start(self.combo, False, False)
+
+ def filter(self, orig_val):
+  if self.combo.get_active() == -1:
+   return True
+
+  filt_iter = self.combo.get_model().get_iter(self.combo.get_active())
+  filt_func = self.combo.get_model().get_value(filt_iter,1)
+  return filt_func(orig_val)
+
+ def filter_checked(self, orig_val):
+  return orig_val == 1
+
+ def filter_not_checked(self, orig_val):
+  return orig_val == 0
+
+ def filter_unset(self, orig_val):
+  return orig_val == -1
+
+ def __changed(self, widget, data=None):
+  self.emit("changed",data)
+
+
+class NumericFilterBox( BlankFilterBox ):
  """NumericFilterCombo: A default number filter class for use in a FilterRow.
 
     Lets the user specify if the row should be displayed based on numeric
@@ -528,13 +722,45 @@ class NumericFilterCombo( BlankFilterCombo ):
   """create a NumericFilterCombo
 
   """
-  BlankFilterCombo.__init__( self )
-  self.append("=",lambda x,y: float(x) == float(y) )
-  self.append("<",lambda x,y: float(x) < float(y) )
-  self.append(">",lambda x,y: float(x) > float(y) )
-  self.append("<=",lambda x,y: float(x) <= float(y) )
-  self.append(">=",lambda x,y:float(x) >= float(y) )
+  BlankFilterBox.__init__( self )
+  self.append("=",self._equals )
+  self.append("<",self._less_than )
+  self.append(">",self._greater_than )
+  self.append("<=",self._less_than_equals)
+  self.append(">=",self._greater_than_equals )
 
+ def _equals(self, orig_val):
+  try:
+   return float(orig_val) == float(self.entry.get_text())
+  except:
+   return True
+
+ def _less_than(self, orig_val):
+  try:
+   return float(orig_val) < float(self.entry.get_text())
+  except:
+   return True
+
+ def _greater_than(self, orig_val):
+  try:
+   return float(orig_val) > float(self.entry.get_text())
+  except:
+   return True
+
+ def _less_than_equals(self, orig_val):
+  try:
+   return float(orig_val) <= float(self.entry.get_text())
+  except:
+   return True
+
+ def _greater_than_equals(self, orig_val):
+  try:
+   return float(orig_val) >= float(self.entry.get_text())
+  except:
+   return True
+
+def __delete_test(button, grid):
+    grid.remove_selected_rows(delete=True)
 
 if __name__ == "__main__":
     """creates a test CouchGrid if called directly"""
@@ -547,27 +773,36 @@ if __name__ == "__main__":
     win.show()
 
     #create a top level container
-    vbox = gtk.VBox(False, False)
+    vbox = gtk.VBox(False, 10)
     vbox.show()
     win.add(vbox)
 
     #create a test widget with test database values
-    dicts = [{"ID": 0, "key?": True, "tags": "aaa bbb ccc"},
-                 {"ID": 1, "key?": False, "tags": "bbb ccc ddd"},
-                 {"ID": 2, "key?": True, "tags": "ccc ddd eee"},
-                 {"ID": 3, "key?": False, "tags": "ddd eee fff"},
-                 {"ID": 4, "key?": True, "tags": "eee fff ggg"}]
+    dicts = [{"ID": 0, "key?": True, "tags": "aaa bbb ccc", "string":"aaaaaaa","date":"2010-08-01"},
+                 {"ID": 1, "key?": False, "tags": "bbb ccc ddd", "string":"bbbbbbb","date":"2010-08-01"},
+                 {"ID": 2, "key?": True, "tags": "ccc ddd eee", "string":"cccccccc","date":"2010-09-01"},
+                 {"ID": 3, "key?": False, "tags": "ddd eee fff", "string":"dddddddd","date":"2010-10-01"},
+                 {"ID": 4, "key?": True, "tags": "eee fff ggg", "string":"eeeeeeee","date":"2010-11-01"}]
 
     database_name = "couch_widget_test"
     record_type = "couch_grid_filter_test"
-    hints = {}
-    grid = CouchGrid(database_name, record_type=record_type, dictionaries=dicts)
+    grid = CouchGrid(database_name, record_type=record_type, dictionaries=dicts, editable=True)
+    grid.columns["tags"].set_title("modified title")
     grid.show()
 
+
+    hints = {}
     filt = GridFilter(grid,hints)
     filt.show()
-    vbox.pack_start(filt, False, True)
-    vbox.pack_end(grid, False, True)
+    vbox.pack_start(filt, False, False)
+    vbox.pack_end(grid, True, True)
 
+    delete_button = gtk.Button("Delete Selected")
+    delete_button.connect("clicked",__delete_test,grid)
+    delete_button.show()
+
+
+    vbox.pack_start(delete_button,False, False)
     gtk.main()
 
+
